@@ -14,7 +14,7 @@ import datetime
 from collections import defaultdict
 
 
-__version__ = '1.22.0'
+__version__ = '1.22.4'
 _PARAMS = re.compile(r'{\w+}')
 
 # Implementation note:  This file is intended to be a standalone file
@@ -1912,6 +1912,14 @@ class Blueprint(DecoratorAPI):
         self._current_app = None
         self._lambda_context = None
 
+    @property
+    def log(self):
+        if self._current_app is None:
+            raise RuntimeError(
+                "Can only access Blueprint.log if it's registered to an app."
+            )
+        return self._current_app.log
+
     @property
     def current_request(self):
         if self._current_app is None:
